###############################################################################
## Author: V. Agudetse
## Description: Example script for seasonal downscaling.
###############################################################################

# Load modules
source("modules/Loading/Loading.R")
source("modules/Units/Units.R")
source("modules/Downscaling/Downscaling.R")
source("modules/Skill/Skill.R")
source("modules/Saving/Saving.R")
source("modules/Visualization/Visualization.R")

# Read recipe
recipe_file <- "recipes/atomic_recipes/recipe_seasonal_downscaling.yml"
recipe <- prepare_outputs(recipe_file)

# Load datasets
data <- Loading(recipe)
# compute anomalies
clim_hcst <- Apply(data$hcst$data, target_dims = c('syear','ensemble'), mean, na.rm = T)$output1
clim_obs <- Apply(data$obs$data, target_dims = c('syear','ensemble'), mean, na.rm = T)$output1
data$hcst$data <- Ano(data = data$hcst$data, clim = clim_hcst)
data$obs$data <- Ano(data = data$obs$data, clim = clim_obs) 
# Change units
data <- Units(recipe, data)
# Downscale datasets
data <- Downscaling(recipe, data)
# Compute skill metrics 
skill_metrics <- Skill(recipe, data)
# Compute percentiles and probability bins
probabilities <- Probabilities(recipe, data)
# Plot data
Visualization(recipe, data, skill_metrics, probabilities, significance = T)
